<?php
/**
 * Admin Registration class
 *
 * @since 1.7.0
 */

// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Plugin class
 **/
if( ! class_exists( 'CT_DB_Pro_Admin_Registration' ) ) {

	class CT_DB_Pro_Admin_Registration {

		public function __construct() {
			//
		}
		
		/**
		 * Initialize the class and start calling our hooks and filters
		 * @since 1.7.0
		 */
		public function init() {
			add_action( 'load-users.php', array( $this, 'approve_user' ) );
			add_action( 'admin_init', array( $this, 'approve_user_remotely' ) );
			add_filter( 'user_row_actions', array( $this, 'user_table_actions' ), 10, 2 );
			
			add_action( 'admin_notices', array( $this, 'user_approved' ) );
		}
		
		/**
		 * Approve user from dashboard
		 */
		public function approve_user() {
			if( ! current_user_can( 'edit_users' ) ) {
				return;
			}
			if ( isset( $_GET['action'] ) && $_GET['action'] == 'approve' && isset( $_GET['user'] ) ) {
				check_admin_referer( 'ctdb_approve_user' );
				
				$url = remove_query_arg( array( 'action' ), wp_get_referer() );
				if ( ! $url ) {
					$url = admin_url( 'users.php' );
				}
				
				// Approve this user by updating their role
				$options = get_option( 'ctdb_user_settings' );
				$role = $options['new_user_role'];
				
				$user_id = absint( $_GET['user'] );
				
				$user_update = wp_update_user( 
					array(
						'ID'	=>	$user_id,
						'role'	=>	$role
					)
				);
				
				if( ! is_wp_error( $user_update ) ) {
					$this->email_user( $user_id );
					$url = add_query_arg(
						array(
							'user_approved'	=> 'true'
						),
						$url
					);
				}
				
				wp_redirect( $url );
				exit;
			}
		}
		
		/**
		 * Approve user from email link
		 */
		public function approve_user_remotely() {
			if( ! current_user_can( 'edit_users' ) ) {
				return;
			}
			
			if ( isset( $_GET['admin_activate_code'] ) && isset( $_GET['user_id'] ) ) {
				
				// An approval link has been clicked
				$user_id = intval( $_GET['user_id'] );
				// Get the activation key of the user ID in the URL
				$user_activation = get_user_meta( $user_id, 'activate_key', true );

				$is_pending = false;
				$user = new WP_User( $user_id );
				foreach( $user -> roles as $role ) {
					if( $role == 'pending' ) {
						$is_pending = true;
					}
				}

				// Only update if role is still pending
				if( $is_pending && $_GET['admin_activate_code'] == $user_activation ) {
				
					// The user ID and activation code match so we'll register this user
					$options = get_option( 'ctdb_user_settings' );
					$role = $options['new_user_role'];
					
					$user_update = wp_update_user( 
						array(
							'ID'	=>	$user_id,
							'role'	=>	$role
						)
					);
					
					if( ! is_wp_error( $user_update ) ) {
						$this->email_user( $user_id );
						add_action( 'admin_notices', array( $this, 'success_notice' ) );
					}
					
				}
			}
		}
		
		public function user_table_actions( $actions, $user ) {
			if ( $user->ID == get_current_user_id() ) {
				return $actions;
			}
			$role = $this->get_user_role( $user->ID );
			$approve_link = add_query_arg( array( 'action' => 'approve', 'user' => $user->ID ) );
			$approve_link = remove_query_arg( array( 'new_role' ), $approve_link );
			$approve_link = wp_nonce_url( $approve_link, 'ctdb_approve_user' );

			$approve_action = '<a href="' . esc_url( $approve_link ) . '">' . __( 'Approve', 'discussion-board-pro' ) . '</a>';

			if ( $role == 'pending' ) {
				$actions[] = $approve_action;
			}
			return $actions;
		}
		
		/**
		 * Initialize the class and start calling our hooks and filters
		 * @since 1.5.0
		 */
		public function get_user_role( $user_ID ) {
			$user = new WP_User( $user_ID );
			foreach( $user->roles as $role ) {
				if( $role == 'pending' || $role == 'rejected' ) {
					return $role;
				}
			}
			return ( array ) $user -> roles;
		}
		
		public function success_notice() { ?>
			<div class="notice notice-success">
				<?php printf( '<p>%s</p>', __( 'User approved', 'discussion-board-pro' ) ); ?>
			</div>
		<?php }
		
		public function user_approved() { 
			if( isset( $_GET['user_approved'] ) ) { ?>
				<div class="notice notice-success">
					<?php printf( '<p>%s</p>', __( 'User approved', 'discussion-board-pro' ) ); ?>
				</div>
			<?php }
		}
		
		public function email_user( $user_id ) {
			$login_url = wp_login_url();
			$login_page_id = ctdb_get_login_page_id();
			if( ! $login_page_id ) {
				$login_url = wp_login_url();
			} else {
				$login_url = get_permalink( $login_page_id );
			}
			$user = get_userdata( $user_id );
			$to = $user->user_email;
			$subject = get_bloginfo( 'name' ) . ': ' . __( 'Your registration has been approved', 'discussion-board-pro' );
			$message = sprintf( 
				'<p>%s</p><p><a href="%s">%s</a></p>',
				__( 'Congratulations. Your registration has been approved. Please log in using the link below:', 'discussion-board-pro' ),
				esc_url( $login_url ),
				esc_url( $login_url )
			);
			
			// Set HTML content type
			add_filter( 'wp_mail_content_type', 'ctdb_set_html_content_type' );

			wp_mail( $to, $subject, $message );

			// Reset content-type to avoid conflicts -- http://core.trac.wordpress.org/ticket/23578
			remove_filter( 'wp_mail_content_type', 'ctdb_set_html_content_type' );
			
		}
	
	}
	
	$CT_DB_Pro_Admin_Registration = new CT_DB_Pro_Admin_Registration();
	$CT_DB_Pro_Admin_Registration->init();
	
}